@@ -19,12 +19,12 @@ class FileProcessCache:
         return self.entries
 
     def load_cache(self) -> List[Path]:
-        self.create_dir(self.cache_dir)
         self.entries = [Path(f) for f in glob.glob(str(self.cache_dir) + "\*." + self.extension)]
         self.entries.sort()
         return self.entries
 
     def move_to_processed(self, entry: Path) -> Path:
+        self.create_dir(self.store_dir)
         self.entries.remove(entry)
         dest = Path(self.store_dir, entry.name)
         os.rename(str(entry), dest)
